@@ -12,7 +12,8 @@ from cyberfusion.ClusterSupport.enums import IPAddressFamily
 from cyberfusion.ClusterSupport.nodes import NodeGroup
 from cyberfusion.ClusterSupport.task_collections import TaskCollection
 
-ENDPOINT_CLUSTERS = "clusters"
+ENDPOINT_PUBLIC_CLUSTERS = "/api/v1/clusters"
+ENDPOINT_INTERNAL_CLUSTERS = "/internal/api/v1/clusters"
 
 
 class MeilisearchEnvironment(str, Enum):
@@ -81,6 +82,7 @@ class PHPExtension(str, Enum):
     TIDEWAYS: str = "tideways"
     MAILPARSE: str = "mailparse"
     UV: str = "uv"
+    AMQP: str = "amqp"
 
 
 class ClusterGroup(str, Enum):
@@ -309,7 +311,7 @@ class Cluster(APIObjectInterface):
         load_balancing_method: Optional[LoadBalancingMethod] = None,
     ) -> TaskCollection:
         """Create object."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}"
+        url = ENDPOINT_PUBLIC_CLUSTERS
         data = {
             "groups": groups,
             "unix_users_home_directory": unix_users_home_directory,
@@ -374,7 +376,7 @@ class Cluster(APIObjectInterface):
 
         # Get object and set attributes on local class
 
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{obj.object_id}"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{obj.object_id}"
 
         self.support.request.GET(url)
         response = self.support.request.execute()
@@ -387,7 +389,7 @@ class Cluster(APIObjectInterface):
 
     def update(self) -> None:
         """Update object."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}"
         data = {
             "id": self.id,
             "name": self.name,
@@ -450,7 +452,7 @@ class Cluster(APIObjectInterface):
 
     def delete(self) -> None:
         """Delete object."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}"
 
         self.support.request.DELETE(url)
         self.support.request.execute()
@@ -459,7 +461,7 @@ class Cluster(APIObjectInterface):
 
     def get_borg_public_ssh_key(self) -> str:
         """Get Borg public SSH key."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/borg-ssh-key"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}/borg-ssh-key"
 
         self.support.request.GET(url)
         response = self.support.request.execute()
@@ -468,7 +470,7 @@ class Cluster(APIObjectInterface):
 
     def get_common_properties(self) -> dict[str, Any]:
         """Get common properties."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/common-properties"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/common-properties"
 
         self.support.request.GET(url)
 
@@ -476,7 +478,7 @@ class Cluster(APIObjectInterface):
 
     def get_ip_addresses(self) -> dict[str, Any]:
         """Get IP addresses."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/ip-addresses"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}/ip-addresses"
 
         self.support.request.GET(url)
 
@@ -490,7 +492,7 @@ class Cluster(APIObjectInterface):
         address_family: IPAddressFamily,
     ) -> TaskCollection:
         """Create IP address."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/ip-addresses"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}/ip-addresses"
         data = {
             "service_account_name": service_account_name,
             "dns_name": dns_name,
@@ -507,7 +509,7 @@ class Cluster(APIObjectInterface):
 
     def delete_ip_address(self, ip_address: str) -> TaskCollection:
         """Delete IP address."""
-        url = f"/api/v1/{ENDPOINT_CLUSTERS}/{self.id}/ip-addresses/{ip_address}"
+        url = f"{ENDPOINT_PUBLIC_CLUSTERS}/{self.id}/ip-addresses/{ip_address}"
 
         self.support.request.DELETE(url)
         response = self.support.request.execute()
